Enum type_info::FieldId
[−]
[src]
pub enum FieldId<'a> {
Unnamed(usize),
Named(&'a str),
}A locally unique identifier for a field within a certain type.
Variants
Unnamed(usize)An unnamed field with the specified index in a tuple-like struct; e.g. the 0 in foo.0.
Named(&'a str)A named field in a struct, e.g. the name in foo.name.