Enum type_info::Fields [] [src]

pub enum Fields {
    Named(FieldsNamed),
    Unnamed(FieldsUnnamed),
    Unit,
}

A set of fields associated with a type or enum variant.

Variants

A set of named fields.

A set of index-addressed fields

The empty set of fields, applicable to unit structs or enum variants.

Methods

impl Fields
[src]

[src]

Convenience method for getting all of the fields, ignoring whether they are named or unnamed.