Struct type_info::Type
[−]
[src]
pub struct Type {
pub id: TypeId,
pub module: &'static str,
pub ident: &'static str,
pub data: Data,
}Type information for a type that implements TypeInfo.
Fields
id: TypeId
The globally unique identifier for this type.
module: &'static str
The module in which this type was defined.
This is using unrooted syntax à la foo::bar.
ident: &'static str
The identifier of this type within its module.
data: Data
Additional data about this type definition.
Methods
impl Type[src]
pub fn fields(&self) -> &'static [Field][src]
Convenience method for getting all of the struct fields of this type.
pub fn variants(&self) -> &'static [Variant][src]
Convenience method for getting all of the enum variants of this type.