TryTypeInfo

Trait TryTypeInfo 

pub trait TryTypeInfo {
    const TRY_TYPE: Option<&'static Type>;
}
A trait that is implemented for every type to conditionally determine whether it exposes type information.

Required Associated Constants

const TRY_TYPE: Option<&'static Type>

The constant statically known type information for this type, or None if the type does not implement TypeInfo.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> TryTypeInfo for T

Source

const TRY_TYPE: Option<&'static Type> = None

Source

impl<T> TryTypeInfo for T
where T: TypeInfo,

Source

const TRY_TYPE: Option<&'static Type>