Enum type_info::Fields
[−]
[src]
pub enum Fields {
Named(FieldsNamed),
Unnamed(FieldsUnnamed),
Unit,
}A set of fields associated with a type or enum variant.
Variants
Named(FieldsNamed)A set of named fields.
Unnamed(FieldsUnnamed)A set of index-addressed fields
UnitThe empty set of fields, applicable to unit structs or enum variants.
Methods
impl Fields[src]
pub fn fields(&self) -> &'static [Field][src]
Convenience method for getting all of the fields, ignoring whether they are named or unnamed.