Trait type_info::TryTypeInfo
[−]
[src]
pub trait TryTypeInfo {
const TRY_TYPE: Option<&'static Type>;
}A trait that is implemented for every type to conditionally determine whether it exposes type information.
Associated Constants
const TRY_TYPE: Option<&'static Type>
The constant statically known type information for this type, or None if the type does not
implement TypeInfo.
Implementors
impl<T> TryTypeInfo for Timpl<T> TryTypeInfo for T where
T: TypeInfo,